# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CESNET Prague.
#
# CIS theses repository is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.


"""JSON schemas.

JSON schemas are used to define the structure of the record data of your
instance.

The documentation of
`Invenio-JSONSchemas <https://invenio-jsonschemas.readthedocs.io/>`_
describes their usage and configuration options.
"""
